@@ -7,11 +7,15 @@ from . import vias
 from .. import config
 
 
-def query(isbn, processor='serial'):
+def query(isbn, processor=None):
     """
     Query function for the `merge provider` (waterfall model)
     """
-    processor = config.options.get('VIAS_MERGE', processor)
+    if not processor:
+        processor = config.options.get('VIAS_MERGE', processor)
+        if not processor:     # pragma: no cover
+            processor = 'serial'
+
     named_tasks = (('wcat', qwcat), ('goob', qgoob))
     if processor == 'parallel':
         results = vias.parallel(named_tasks, isbn)
@@ -28,7 +32,7 @@ def query(isbn, processor='serial'):
     if md and rg:
         md.merge(rg, ('Authors'))
         return md.value
-    if not md and rg:  # pragma: no cover
+    if not md and rg:       # pragma: no cover
         md = Metadata(rg)
         return md.value
-    return md.value if not rg and rw else None
+    return md.value if not rg and rw else None  # pragma: no cover
