@@ -6,6 +6,7 @@ Queries the openlibrary.org service for metadata
 import logging
 from .webquery import query as wquery
 from .data import stdmeta
+from ..bouth23 import u
 from .exceptions import NoDataForSelectorError, RecordMappingError
 
 
@@ -24,14 +25,14 @@ def _mapper(isbn, records):
     try:
         # mapping: canonical <- records
         canonical = {}
-        canonical['ISBN-13'] = unicode(isbn)
-        canonical['Title'] = records.get('title', u'').replace(' :', ':')
+        canonical['ISBN-13'] = u(isbn)
+        canonical['Title'] = records.get('title', u('')).replace(' :', ':')
         canonical['Authors'] = [a['name'] for a in
-                                records.get('authors', ({'name': u''},))]
+                                records.get('authors', ({'name': u('')},))]
         canonical['Publisher'] = records.get('publishers',
-                                             [{'name': u''}, ])[0]['name']
-        canonical['Year'] = records.get('publish_date', u',').split(',')[1]
-    except:
+                                             [{'name': u('')}, ])[0]['name']
+        canonical['Year'] = records.get('publish_date', u(',')).split(',')[1]
+    except:   # pragma: no cover
         raise RecordMappingError(isbn)
     # call stdmeta for extra cleanning and validation
     return stdmeta(canonical)
@@ -44,7 +45,7 @@ def _records(isbn, data):
     try:
         # put the selected data in records
         records = data['ISBN:%s' % isbn]
-    except:
+    except:   # pragma: no cover
         raise NoDataForSelectorError(isbn)
 
     # map canonical <- records
